============
Installation
============

Deprecation Factory is meant to be a project dependency and not installed
directly by the end user. As such, we assume that you know how to manage
depdencies for your project.

Deprecation Factory only depends on the Python standard library keeping it
lightweight. This package is available both on `PyPi`_ and `conda-forge`_.


.. _PyPi: https://pypi.org/project/wabisabi/
.. _conda-forge: https://anaconda.org/conda-forge/wabisabi/
